==> lingotek_overrides-3.7.2.tar.gz: lingotek_overrides/src/Plugin/lingotek_overrides/FormField/ModerationState.php <==
<?php

namespace Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormField;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\Core\Entity\RevisionableStorageInterface;
use Drupal\Core\Entity\TranslatableInterface;

/**
 * Defines a Lingotek form-field plugin for the moderation state.
 *
 * Applies to the entity's latest revision.
 *
 * @LingotekOverridesFormField(
 *   id = "lingotek_overrides_moderation_state",
 *   title = @Translation("Latest revision"),
 *   weight = 951,
 *   form_ids = {
 *     "lingotek_management",
 *     "lingotek_entity_management",
 *   }
 * )
 */
class ModerationState extends Status {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(array $arguments = []) {
    return !empty($this->moderationInformation);
  }

  /**
   * {@inheritdoc}
   */
  public function getHeader($entity_type_id = NULL) {
    return $this->weight($this->getPluginDefinition()['title']);
  }

  /**
   * {@inheritdoc}
   */
  public function getData(EntityInterface $entity) {
    $statuses = [];

    if ($entity instanceof TranslatableInterface) {
      /** @var \Drupal\Core\Entity\RevisionableStorageInterface $storage */
      $storage = $this->entityTypeManager->getStorage($entity->getEntityTypeId());

      if ($storage instanceof RevisionableStorageInterface) {
        if ($entity = $storage->loadRevision($storage->getLatestRevisionId($entity->id()))) {
          /** @var \Drupal\Core\Entity\TranslatableInterface $entity */
          $languages = array_keys($entity->getTranslationLanguages());

          foreach ($languages as $language) {
            /** @var \Drupal\Core\Entity\ContentEntityInterface $translation */
            $translation = $entity->getTranslation($language);
            $statuses[$this->getStatus($translation)][] = $language;
          }
        }
      }
    }

    return $this->weight($this->buildStatuses($statuses));
  }

}

==> lingotek_overrides-3.7.3.tar.gz: lingotek_overrides/src/Plugin/lingotek_overrides/FormField/ModerationState.php <==
<?php

namespace Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormField;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\RevisionableStorageInterface;
use Drupal\Core\Entity\TranslatableInterface;

/**
 * Defines a Lingotek form-field plugin for the moderation state.
 *
 * Applies to the entity's latest revision.
 *
 * @LingotekOverridesFormField(
 *   id = "lingotek_overrides_moderation_state",
 *   title = @Translation("Latest revision"),
 *   weight = 951,
 *   form_ids = {
 *     "lingotek_management",
 *     "lingotek_entity_management",
 *   }
 * )
 */
class ModerationState extends Status {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(array $arguments = []) {
    return !empty($this->moderationInformation);
  }

  /**
   * {@inheritdoc}
   */
  public function getHeader($entity_type_id = NULL) {
    return $this->weight($this->getPluginDefinition()['title']);
  }

  /**
   * {@inheritdoc}
   */
  public function getData(EntityInterface $entity) {
    $statuses = [];

    if ($entity instanceof TranslatableInterface) {
      /** @var \Drupal\Core\Entity\TranslatableRevisionableStorageInterface $storage */
      $storage = $this->entityTypeManager->getStorage($entity->getEntityTypeId());
      $entity_id = $entity->id();

      if ($storage instanceof RevisionableStorageInterface) {
        $languages = array_keys($this->languageManager->getLanguages());

        foreach ($languages as $language) {
          if ($revision_id = $storage->getLatestTranslationAffectedRevisionId($entity_id, $language)) {
            /** @var \Drupal\Core\Entity\TranslatableInterface $revision */
            if ($revision = $storage->loadRevision($revision_id)) {
              /** @var \Drupal\Core\Entity\ContentEntityInterface $translation */
              $translation = $revision->getTranslation($language);
              $statuses[$this->getStatus($translation)][] = $language;
            }
          }
        }
      }
    }

    return $this->weight($this->buildStatuses($statuses));
  }

}
